@@ -7,8 +7,6 @@
  * be passed to the template file.                                         *
  *                                                                         *
  ***************************************************************************/
-/* $XFree86: xc/config/imake/imake.c,v 3.63tsi Exp $ */
-
 /*
  *
 Copyright (c) 1985, 1986, 1987, 1998 The Open Group
@@ -397,11 +395,11 @@ main(int argc, char *argv[])
 		if ((tmpfd = fopen(tmpMakefile, "w+")) == NULL)
 		   LogFatal("Cannot create temporary file %s.", tmpMakefile);
 	} else {
-#ifdef HAS_MKSTEMP
+#ifdef HAVE_MKSTEMP
 		int fd;
 #endif
 		tmpMakefile = Strdup(tmpMakefile);
-#ifndef HAS_MKSTEMP
+#ifndef HAVE_MKSTEMP
 		if (mktemp(tmpMakefile) == NULL ||
 		    (tmpfd = fopen(tmpMakefile, "w+")) == NULL) {
 		   LogFatal("Cannot create temporary file %s.", tmpMakefile);
@@ -1771,11 +1769,11 @@ CleanCppInput(char *imakefile)
 		    strcmp(ptoken, "pragma") &&
 		    strcmp(ptoken, "undef")) {
 		    if (outFile == NULL) {
-#ifdef HAS_MKSTEMP
+#ifdef HAVE_MKSTEMP
 			int fd;
 #endif
 			tmpImakefile = Strdup(tmpImakefile);
-#ifndef HAS_MKSTEMP
+#ifndef HAVE_MKSTEMP
 			if (mktemp(tmpImakefile) == NULL ||
 			    (outFile = fopen(tmpImakefile, "w+")) == NULL) {
 			    LogFatal("Cannot open %s for write.",
@@ -1978,8 +1976,6 @@ ReadLine(FILE *tmpfd, char *tmpfname)
 #endif	/* !SYSV */
 		initialized = TRUE;
 	    fprintf (tmpfd, "# Makefile generated by imake - do not edit!\n");
-	    fprintf (tmpfd, "# %s\n",
-		"$Xorg: imake.c,v 1.6 2001/02/09 02:03:15 xorgcvs Exp $");
 	}
 
 	for (p1 = pline; p1 < end; p1++) {
